# -*- coding: utf-8 -*-
import logging
import os


class Logger(logging.Logger):

    def __init__(self,
                 logger_name="logger",
                 log_path="logs\log"):
        super().__init__(logger_name)
        self.log_path = log_path

        self._mk_logs_dir()
        self._fmt_output()

    def _fmt_output(self):

        console_fmt = logging.Formatter(
            fmt="%(name)s--->%(levelname)s--->%(asctime)s--->%(message)s")
        file_fmt = logging.Formatter(
            fmt="%(lineno)d--->%(name)s--->%(levelname)s--->%(asctime)s--->%(message)s")

        file_handler = logging.FileHandler(
            self.log_path, mode="a", encoding="utf-8")

        file_handler.setLevel(logging.DEBUG)
        file_handler.setFormatter(file_fmt)
        self.addHandler(file_handler)

        console_handler = logging.StreamHandler()
        console_handler.setLevel(logging.INFO)
        console_handler.setFormatter(console_fmt)
        self.addHandler(console_handler)

    def _mk_logs_dir(self):

        log_dir = os.path.dirname(self.log_path)
        if log_dir and not os.path.exists(log_dir):
            os.mkdir(log_dir)


if __name__ == "__main__":
    Logger().debug("This is one debug message..")



from email.message import Message
import os

import extract_msg
import mailparser
from encoo.logger import Logger


class EmlMessage(object):

    __logger = Logger("emlmessage")

    eml = None
    msg = None

    def __init__(self, fp) -> None:

        try:
            with open(fp) as f:
                eml_str = f.read()
            self.eml = mailparser.parse_from_string(eml_str)
        except UnicodeDecodeError as e:
            self.msg = extract_msg.Message(fp)
        except Exception as e:
            self.__logger.error(f"__init__ {e}")

    def __get_eml(self):
        return {
            "subject": self.eml.headers.get("Subject", ""),
            "from": self.eml.headers.get("From", ""),
            "to": self.eml.headers.get("To", ""),
            "date": self.eml.headers.get("Date", ""),
            "body": self.eml.text_plain}

    def __get_msg(self):
        return {
            "subject": self.msg.subject,
            "from": self.msg.sender,
            "to": self.msg.to,
            "date": self.msg.date,
            "body": self.msg.body
        }

    def extract(self):
        if self.msg is not None:
            return self.__get_msg()
        elif self.eml is not None:
            return self.__get_eml()


if __name__ == "__main__":

    root_dir = r"D:\Repos\encoo_ecs\emls"
    for f in os.listdir(root_dir):
        eml = EmlMessage(os.path.join(root_dir, f)).extract()
        '''print("subject", eml.get("subject"))
        print("from", eml.get("from"))
        print("date", eml.get("date"))'''
        print("body\n", eml.get("body"))
        


from configparser import ConfigParser

import xlrd
from encoo.logger import Logger


class Config(object):

    __cfg_parser = None

    def __init__(self, cfg_path) -> None:
        if cfg_path is not None:
            try:
                cfg_parser = ConfigParser()
                cfg_parser.read(cfg_path, encoding='utf-8')
                self.__cfg_parser = cfg_parser
            except Exception as e:
                Logger("encoo\config.py").error(f"Config __init__ {e}")

    def get_config(self, section, key=None):

        if key != None:
            return self.__cfg_parser.get(section, key)
        else:
            return self.__cfg_parser.items(section)

    @staticmethod
    def get_excel_cfg(cfg_path, sheet_name=None, inc_header=True):
        data_list = []
        try:
            xls = xlrd.open_workbook(cfg_path, formatting_info=True)

            if sheet_name:
                sheet = xls.sheet_by_name(sheet_name)
            else:
                sheet = xls.sheet_by_index(0)
            row_start_idx = 0
            if inc_header:
                row_start_idx = 1

            for row in range(row_start_idx, sheet.nrows):
                data_list.append(sheet.row_values(row))
        except Exception as e:
            Logger("encoo\config.py").error(f"get_excel_cfg {e}")

        return data_list


if __name__ == "__main__":
    cfg = Config.get_excel_cfg(
        r"C:\Users\renjunfeng\Desktop\流水汇总文件2023-03-28.xls", inc_header=True)
    print(len(cfg))
    
    cfg= Config(r"D:\Repos\pbc_gov\cfg\config.cfg").get_config("file","zh_file_dir")
    print(cfg)



from setuptools import find_packages, setup

setup(
    name='encoo',
    version='1.0.1',
    packages=find_packages(),
    install_requires=['xlwt>=1.3.0', 'xlrd>=2.0.1',
                      'configparser>=5.3.0', 'mail-parser>=3.15.0',
                      'extract-msg>=0.40.0'],
)


# 打包 python .\setup.py sdist bdist_wheel
# 上传 twine upload dist/*

# 安装 pip install encoo==1.0.0  -i https://www.pypi.org/simple/
